@@ -42,7 +42,7 @@ class LHEEventInfo(object):
 
 
 class LHEParticle(object):
-    fieldnames = fieldnames = [
+    fieldnames = [
         "id",
         "status",
         "mother1",
@@ -257,7 +257,8 @@ def visualize(event, outputname):
     nx.nx_pydot.write_dot(g, "event.dot")
 
     p = subprocess.Popen(["dot2tex", "event.dot"], stdout=subprocess.PIPE)
-    tex = p.stdout.read().decode()
+    # TODO: Remove explicit str wrapping once Python 2 dropped
+    tex = str(p.stdout.read().decode())
     tex2pix.Renderer(tex).mkpdf(outputname)
     subprocess.check_call(["pdfcrop", outputname, outputname])
     os.remove("event.dot")
